@@ -8,9 +8,9 @@
  * Copyright 2000 Ximian, Inc.
  */
 #include <config.h>
+#include <glib/gi18n-lib.h>
 #include <bonobo/Bonobo.h>
 #include <bonobo/bonobo-arg.h>
-#include <bonobo/bonobo-i18n.h>
 #include <bonobo/bonobo-main.h>
 #include <bonobo/bonobo-exception.h>
 #include <string.h>
@@ -31,7 +31,7 @@ bonobo_config_bag_finalize (GObject *object)
 	BonoboConfigBag *cb = BONOBO_CONFIG_BAG (object);
 
 	g_free (cb->path);
-	g_object_unref (G_OBJECT (cb->conf_client));
+	g_object_unref (cb->conf_client);
 
 	parent_class->finalize (object);
 }
@@ -60,7 +60,7 @@ impl_Bonobo_PropertyBag_getKeys (PortableServer_Servant  servant,
 	slist = gconf_client_all_entries (cb->conf_client, path, &err);
 	g_free (path);
 	if (err) {
-		bonobo_exception_general_error_set (ev, NULL, err->message);
+		bonobo_exception_general_error_set (ev, NULL, "%s", err->message);
 		g_error_free (err);
 		return CORBA_OBJECT_NIL;
 	}
@@ -106,7 +106,7 @@ impl_Bonobo_PropertyBag_getType (PortableServer_Servant  servant,
 	value = gconf_client_get (cb->conf_client, path, &err);
 	g_free (path);
 	if (err) {
-		bonobo_exception_general_error_set (ev, NULL, err->message);
+		bonobo_exception_general_error_set (ev, NULL, "%s", err->message);
 		g_error_free (err);
 		return CORBA_OBJECT_NIL;
 	}
@@ -137,7 +137,7 @@ bonobo_arg_new_from_gconf_value (GConfValue *value)
 {
         if (value == NULL)
                 return bonobo_arg_new (BONOBO_ARG_NULL);
-        
+
 	switch (value->type) {
 	case GCONF_VALUE_STRING :
 		return bonobo_arg_new_from (BONOBO_ARG_STRING,
@@ -168,7 +168,7 @@ impl_Bonobo_PropertyBag_getValue (PortableServer_Servant  servant,
 	char            *path;
 	GConfValue      *value;
 	GError          *err = NULL;
- 
+
 	if (strchr (key, '/')) {
 		bonobo_exception_set (ev, ex_Bonobo_PropertyBag_NotFound);
 		return NULL;
@@ -179,7 +179,7 @@ impl_Bonobo_PropertyBag_getValue (PortableServer_Servant  servant,
 	value = gconf_client_get (cb->conf_client, path, &err);
 	g_free (path);
 	if (err) {
-		bonobo_exception_general_error_set (ev, NULL, err->message);
+		bonobo_exception_general_error_set (ev, NULL, "%s", err->message);
 		g_error_free (err);
 		return CORBA_OBJECT_NIL;
 	}
@@ -190,7 +190,7 @@ impl_Bonobo_PropertyBag_getValue (PortableServer_Servant  servant,
         return bonobo_arg_new_from_gconf_value (value);
 }
 
-static void 
+static void
 impl_Bonobo_PropertyBag_setValue (PortableServer_Servant  servant,
 				  const CORBA_char       *key,
 				  const CORBA_any        *value,
@@ -199,7 +199,7 @@ impl_Bonobo_PropertyBag_setValue (PortableServer_Servant  servant,
 	BonoboConfigBag *cb = GET_BAG_FROM_SERVANT (servant);
 	char            *path;
 	GError          *err = NULL;
-	
+
 	if (strchr (key, '/')) {
 		bonobo_exception_set (ev, ex_Bonobo_PropertyBag_NotFound);
 		return;
@@ -235,7 +235,7 @@ impl_Bonobo_PropertyBag_setValue (PortableServer_Servant  servant,
 	g_free (path);
 
 	if (err) {
-		bonobo_exception_general_error_set (ev, NULL, err->message);
+		bonobo_exception_general_error_set (ev, NULL, "%s", err->message);
 		g_error_free (err);
 	}
 }
@@ -264,7 +264,7 @@ impl_Bonobo_PropertyBag_getValues (PortableServer_Servant servant,
 	slist = gconf_client_all_entries (cb->conf_client, path, &err);
 	g_free (path);
 	if (err) {
-		bonobo_exception_general_error_set (ev, NULL, err->message);
+		bonobo_exception_general_error_set (ev, NULL, "%s", err->message);
 		g_error_free (err);
 		return CORBA_OBJECT_NIL;
 	}
@@ -285,7 +285,7 @@ impl_Bonobo_PropertyBag_getValues (PortableServer_Servant servant,
                 value = gconf_entry_get_value (entry);
 
                 arg = bonobo_arg_new_from_gconf_value (value);
-                
+
 		retval->_buffer[n].value = *arg;
 	}
 
@@ -294,7 +294,7 @@ impl_Bonobo_PropertyBag_getValues (PortableServer_Servant servant,
 	return retval;
 }
 
-static void                  
+static void
 impl_Bonobo_PropertyBag_setValues (PortableServer_Servant servant,
 				   const Bonobo_PropertySet *set,
 				   CORBA_Environment *ev)
@@ -302,9 +302,9 @@ impl_Bonobo_PropertyBag_setValues (PortableServer_Servant servant,
 	int i;
 
 	for (i = 0; i < set->_length; i++) {
-		impl_Bonobo_PropertyBag_setValue (servant, 
+		impl_Bonobo_PropertyBag_setValue (servant,
 						  set->_buffer [i].name,
-						  &set->_buffer [i].value, 
+						  &set->_buffer [i].value,
 						  ev);
 		if (BONOBO_EX (ev))
 			return;
@@ -331,7 +331,7 @@ impl_Bonobo_PropertyBag_getDefault (PortableServer_Servant  servant,
 	value = gconf_client_get_default_from_schema (cb->conf_client, path, &err);
 	g_free (path);
 	if (err) {
-		bonobo_exception_general_error_set (ev, NULL, err->message);
+		bonobo_exception_general_error_set (ev, NULL, "%s", err->message);
 		g_error_free (err);
 		return CORBA_OBJECT_NIL;
 	}
@@ -359,7 +359,7 @@ impl_Bonobo_PropertyBag_getDocTitle (PortableServer_Servant  servant,
 	schema = gconf_client_get_schema (cb->conf_client, path, &err);
 	g_free (path);
 	if (err) {
-		bonobo_exception_general_error_set (ev, NULL, err->message);
+		bonobo_exception_general_error_set (ev, NULL, "%s", err->message);
 		g_error_free (err);
 		return NULL;
 	}
@@ -392,7 +392,7 @@ impl_Bonobo_PropertyBag_getDoc (PortableServer_Servant  servant,
 	schema = gconf_client_get_schema (cb->conf_client, path, &err);
 	g_free (path);
 	if (err) {
-		bonobo_exception_general_error_set (ev, NULL, err->message);
+		bonobo_exception_general_error_set (ev, NULL, "%s", err->message);
 		g_error_free (err);
 		return NULL;
 	}
@@ -424,7 +424,7 @@ impl_Bonobo_PropertyBag_getFlags (PortableServer_Servant  servant,
 	entry = gconf_client_get_entry (cb->conf_client, path, NULL, TRUE, &err);
 	g_free (path);
 	if (err) {
-		bonobo_exception_general_error_set (ev, NULL, err->message);
+		bonobo_exception_general_error_set (ev, NULL, "%s", err->message);
 		g_error_free (err);
 		return 0;
 	}
@@ -438,27 +438,6 @@ impl_Bonobo_PropertyBag_getFlags (PortableServer_Servant  servant,
 	return retval;
 }
 
-#if 0
-static void
-notify_cb (BonoboListener    *listener,
-	   const char        *event_name, 
-	   const CORBA_any   *any,
-	   CORBA_Environment *ev,
-	   gpointer           user_data)
-{
-	BonoboConfigBag *cb = BONOBO_CONFIG_BAG (user_data);
-	char *tmp, *ename;
-
-	tmp = bonobo_event_subtype (event_name);
-	ename = g_strconcat ("Bonobo/Property:change:", tmp, NULL); 
-	g_free (tmp);
-
-	bonobo_event_source_notify_listeners (cb->es, ename, any, NULL);
-
-	g_free (ename);
-}
-#endif
-
 BonoboConfigBag *
 bonobo_config_bag_new (const gchar *path)
 {
@@ -475,12 +454,12 @@ bonobo_config_bag_new (const gchar *path)
 	else
 		cb->path = g_strconcat ("/", path, NULL);
 
-	while ((l = strlen (cb->path)) > 1 && path [l - 1] == '/') 
+	while ((l = strlen (cb->path)) > 1 && path [l - 1] == '/')
 		cb->path [l] = '\0';
-	
+
 	cb->es = bonobo_event_source_new ();
 
-	bonobo_object_add_interface (BONOBO_OBJECT (cb), 
+	bonobo_object_add_interface (BONOBO_OBJECT (cb),
 				     BONOBO_OBJECT (cb->es));
 
 	m = g_strconcat ("Bonobo/ConfigDatabase:change", cb->path, ":", NULL);
@@ -502,7 +481,7 @@ bonobo_config_bag_class_init (BonoboConfigBagClass *class)
 {
 	GObjectClass *object_class = (GObjectClass *) class;
 	POA_Bonobo_PropertyBag__epv *epv= &class->epv;
-	
+
 	parent_class = g_type_class_peek_parent (class);
 
 	object_class->finalize = bonobo_config_bag_finalize;
@@ -525,7 +504,7 @@ bonobo_config_bag_init (BonoboConfigBag *cb)
 	/* nothing to do */
 }
 
-BONOBO_TYPE_FUNC_FULL (BonoboConfigBag, 
+BONOBO_TYPE_FUNC_FULL (BonoboConfigBag,
 		       Bonobo_PropertyBag,
 		       PARENT_TYPE,
 		       bonobo_config_bag);
